Learn R Programming

varSelRF (version 0.7-3)

summary.varSelRFBoot: Summary of a varSelRFBoot object

Description

Returns error rate and stability measures of a varSelRFBoot object.

Usage

## S3 method for class 'varSelRFBoot':
summary(object, return.model.freqs = FALSE,
                     return.class.probs = TRUE,
                     return.var.freqs.b.models = TRUE, ...)

Arguments

object
An object of class varSelRFBoot, as returned from varSelRFBoot.
return.model.freqs
If TRUE return a table with the frequencies of the final "models" (sets of selected variables) over all bootstrap replications.
return.class.probs
If TRUE return average class probabilities for each sample based on the out-of-bag probabilites (see varSelRFBoot, the prob.predictions component).
return.var.freqs.b.models
If TRUE return the frequencies of all variables selected from the bootstrap replicates.
...
Not used.

Value

  • If return.class.probs = TRUE a matrix with the average class probabilities for each sample based on the out-of-bag probabilites.

    Regardless of that setting, print out several summaries:

  • Summaries related to the "simplified" random forest on the original dataSuch as the number and identity of the variables selected.
  • Summaries related to the error rate estimateSuch as the .632+ estimate, and some of its components
  • Summaries related to the stability (uniqueness) of the results obtainedSuch as the frequency of the selected variables in the bootstrap runs, the frequency of the selected variables in the boostrap runs that are also among the variables selected from the complete run, the overlap of the bootstrap forests with the forest from the original data set (see varSelRF for the definition of overlap), and (optionally) the frequency of the "models", where a model is the set of variables selected in any particular run.

References

Breiman, L. (2001) Random forests. Machine Learning, 45, 5--32.

Diaz-Uriarte, R. and Alvarez de Andres, S. (2005) Variable selection from random forests: application to gene expression data. Tech. report. http://ligarto.org/rdiaz/Papers/rfVS/randomForestVarSel.html

Efron, B. & Tibshirani, R. J. (1997) Improvements on cross-validation: the .632+ bootstrap method. J. American Statistical Association, 92, 548--560.

See Also

randomForest, varSelRF, varSelRFBoot, plot.varSelRFBoot,

Examples

Run this code
## This is a small example, but can take some time.

x <- matrix(rnorm(25 * 30), ncol = 30)
x[1:10, 1:2] <- x[1:10, 1:2] + 2
cl <- factor(c(rep("A", 10), rep("B", 15)))  

rf.vs1 <- varSelRF(x, cl, ntree = 200, ntreeIterat = 100,
                   vars.drop.frac = 0.2)
rf.vsb <- varSelRFBoot(x, cl,
                       bootnumber = 10,
                       usingCluster = FALSE,
                       srf = rf.vs1)
rf.vsb
summary(rf.vsb)
plot(rf.vsb)

Run the code above in your browser using DataLab