varSelRF.varSelRFBoot(xdata, Class, c.sd = 1,
mtryFactor = 1, ntree = 5000, ntreeIterat = 2000,
vars.drop.frac = 0.2, bootnumber = 200,
whole.range = TRUE,
recompute.var.imp = FALSE,
usingCluster = TRUE,
TheCluster = NULL, srf = NULL, verbose = TRUE, ...)varSelRF.predict.randomForest. This is an array, with
dimensions number of cases by number of bootstrap replicates.predict.randomForest. This is a 3-way array; the last
dimension is the bootstrap replication; for each bootstrap
replication, the 2D array
has dimensions case by number of classes, and each value is the
probability of belonging to that class.number.of.bootsamples, of the solution from each bootstrap
run.number.of.bootsamples. Each
component of this list is an element of class varSelRF
and stores the results from the runs on each bootstrap sample. Diaz-Uriarte, R. and Alvarez de Andres,
S. (2005) Variable selection from random forests: application to gene
expression
data. Tech. report.
Efron, B. & Tibshirani, R. J. (1997) Improvements on cross-validation: the .632+ bootstrap method. J. American Statistical Association, 92, 548--560. Svetnik, V., Liaw, A. , Tong, C & Wang, T. (2004) Application of Breiman's random forest to modeling structure-activity relationships of pharmaceutical molecules. Pp. 334-343 in F. Roli, J. Kittler, and T. Windeatt (eds.). Multiple Classier Systems, Fifth International Workshop, MCS 2004, Proceedings, 9-11 June 2004, Cagliari, Italy. Lecture Notes in Computer Science, vol. 3077. Berlin: Springer.
randomForest,
varSelRF,
summary.varSelRFBoot,
plot.varSelRFBoot,## This is a small example, but can take some time.
x <- matrix(rnorm(25 * 30), ncol = 30)
x[1:10, 1:2] <- x[1:10, 1:2] + 2
cl <- factor(c(rep("A", 10), rep("B", 15)))
rf.vs1 <- varSelRF(x, cl, ntree = 200, ntreeIterat = 100,
vars.drop.frac = 0.2)
rf.vsb <- varSelRFBoot(x, cl,
bootnumber = 10,
usingCluster = FALSE,
srf = rf.vs1)
rf.vsb
summary(rf.vsb)
plot(rf.vsb)Run the code above in your browser using DataLab